/*
 * libsgml -- SGML state machine parsing library.
 *                                                                  
 * Copyright (c) 2002 Uninformed Research (http://www.uninformed.org)
 * All rights reserved.
 *
 * skape
 * mmiller@hick.org
 */
#ifndef _LIBSGML_SGMLEXTENSIONHTML_H
#define _LIBSGML_SGMLEXTENSIONHTML_H

#include "HtmlElement.h"
#include "HtmlText.h"
#include "HtmlComment.h"

#include "HtmlNodeList.h"

#define SGML_EXTENSION_HTML_PARAM_FLAG            0x00000001
#define SGML_EXTENSION_HTML_PARAM_SETKNOWNTAGS    0x00000002

#define SGML_EXTENSION_HTML_FLAG_STRIPELEMENT      (1 << 0)
#define SGML_EXTENSION_HTML_FLAG_STRIPTEXT         (1 << 1)
#define SGML_EXTENSION_HTML_FLAG_STRIPCOMMENT      (1 << 2)
#define SGML_EXTENSION_HTML_FLAG_IGNOREBLANKLINES  (1 << 3)
#define SGML_EXTENSION_HTML_FLAG_ESCAPEUNKNOWNTAGS (1 << 4)

typedef struct _sgml_extension_html {

	HTML_ELEMENT  *rootElement;
	HTML_NODE     *rootNode;

	HTML_ELEMENT  *currElement;

	unsigned char skipNextAttribute;

	unsigned long flags;

	char          **knownTags;

	void (*saveDivert)(struct _sgml_parser *parser, unsigned long newIndex, unsigned long oldState, unsigned long newState, const char *lastBuffer, unsigned long lastBufferSize);	

} SGML_EXTENSION_HTML;

SGML_EXTENSION_HTML *sgmlExtensionHtmlNew(SGML_PARSER *parser);
void sgmlExtensionHtmlDestroy(SGML_PARSER *parser, SGML_EXTENSION_HTML *ext);

void sgmlExtensionHtmlInitialize(SGML_PARSER *parser, void *userContext);
void sgmlExtensionHtmlElementBegin(SGML_PARSER *parser, void *userContext, const char *elementName);
void sgmlExtensionHtmlElementEnd(SGML_PARSER *parser, void *userContext, const char *elementName);
void sgmlExtensionHtmlAttributeNew(SGML_PARSER *parser, void *userContext, const char *attributeName, const char *attributeValue);
void sgmlExtensionHtmlTextNew(SGML_PARSER *parser, void *userContext, const char *text);
void sgmlExtensionHtmlCommentNew(SGML_PARSER *parser, void *userContext, const char *comment);
void sgmlExtensionHtmlDeinitialize(SGML_PARSER *parser, void *userContext);

void sgmlExtensionHtmlSetParam(SGML_PARSER *parser, void *extensionContext, unsigned long param, void *value);
void sgmlExtensionHtmlGetParam(SGML_PARSER *parser, void *extensionContext, unsigned long param, void *value);

HTML_NODE *sgmlExtensionHtmlGetRootNode(SGML_PARSER *parser);

#endif
