/*
 * libsgml -- SGML state machine parsing library.
 *                                                                  
 * Copyright (c) 2002 Uninformed Research (http://www.uninformed.org)
 * All rights reserved.
 *
 * skape
 * mmiller@hick.org
 */
#include <stdlib.h>
#include <stdio.h>

#include "HtmlNode.h"
#include "HtmlElement.h"

HTML_ELEMENT *htmlElementNew(const char *elementName)
{
	return htmlNodeNew(HTML_NODE_TYPE_ELEMENT, elementName, NULL);
}

void htmlElementDestroy(HTML_ELEMENT *element)
{
	htmlNodeDestroy(element);
}

void htmlElementSetAttribute(HTML_ELEMENT *element, const char *name, const char *value)
{
	HTML_NODE *curr, *attr = NULL;

	if ((!element) || (!name) || (!value))
		return;

	curr = htmlNodeFindNodeByName(element->attributes, name);

	if (!curr)
		attr = htmlNodeNew(HTML_NODE_TYPE_ATTRIBUTE, name, value);
	else
		attr = curr;

	if (!element->attributes)
		element->attributes = attr;
	else
		htmlNodeAppendSibling(element->attributes, attr);

	htmlNodeSetNodeValue(attr, value);	
}

void htmlElementUnsetAttribute(HTML_ELEMENT *element, const char *name)
{
	HTML_NODE *attr;

	if ((!element) || (!name))
		return;

	attr = htmlNodeFindNodeByName(element->attributes, name);

	if (attr)
	{
		htmlNodeRemoveNode(NULL, attr);
		htmlNodeDestroy(attr);
	}
}

const char *htmlElementGetAttribute(HTML_ELEMENT *element, const char *name)
{
	HTML_NODE *attr;

	if ((!element) || (!name))
		return NULL;

	attr = htmlNodeFindNodeByName(element->attributes, name);

	return (attr)?attr->nodeValue:NULL;
}
